unit kz.Dialog.Font;

{$mode ObjFPC}{$H+}

interface

uses
  Forms, StdCtrls, Dialogs, ExtCtrls, Spin, Graphics, Classes;

type

  { TfrmFont }

  TfrmFont = class(TForm)
    btnOk: TButton;
    btnColor: TColorButton;
    lblSize: TLabel;
    lbFonts: TListBox;
    lblColor: TLabel;
    mmoPreview: TMemo;
    pnlColor: TPanel;
    pnlSize: TPanel;
    pnlOptions: TPanel;
    pnlPreview: TPanel;
    pnlSetup: TPanel;
    pnlFonts: TPanel;
    pnlMain: TPanel;
    lblFonts: TStaticText;
    seSize: TSpinEdit;
    procedure btnColorColorChanged(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure FormDestroy(Sender: TObject);
    procedure lbFontsClick(Sender: TObject);
    procedure seSizeChange(Sender: TObject);
  strict private
    FFont: TFont;
    FCaption: string;
    FTitleFonts: string;
    FTitleSize: string;
    FTitleColor: string;
    FTitleButton: string;
    FPreviewLines: TStringList;
  private
    procedure SetCaption(const AValue: string);
    procedure SetTitleFonts(const AValue: string);
    procedure SetTitleSize(const AValue: string);
    procedure SetTitleColor(const AValue: string);
    procedure SetTitleButton(const AValue: string);
    procedure SetPreviewLines(const AValue: TStringList);
  public
  published
    property Font: TFont read FFont;
    property TitleCaption: string read FCaption write SetCaption;
    property TitleFonts: string read FTitleFonts write SetTitleFonts;
    property TitleSize: string read FTitleSize write SetTitleSize;
    property TitleColor: string read FTitleColor write SetTitleColor;
    property TitleButton: string read FTitleButton write SetTitleButton;
    property PreviewLines: TStringList read FPreviewLines write SetPreviewLines;
  end;

implementation


{$R *.lfm}

{ TfrmFont }

procedure TfrmFont.FormCreate(Sender: TObject);
var
  s: string;
begin
  FFont := TFont.Create;
  try
    FFont.Assign(Self.Font);
  finally
  end;
  lbFonts.Items.Assign(Screen.Fonts);
  seSize.Value := Round((Abs(GetFontData(FFont.Handle).Height) * 72 / FFont.PixelsPerInch));
  s := GetFontData(FFont.Handle).Name;
  lbFonts.ItemIndex := lbFonts.Items.IndexOf(s);
  FFont.Name := s;
  SetCaption('Choose a Font');
  SetTitleFonts('[ Fonts ]');
  SetTitleSize('Size');
  SetTitleColor('Color');
  SetTitleButton('Accept');
  FPreviewLines := TStringList.Create;
  try
    FPreviewLines.Add('Lazarus is a free cross-platform visual integrated development environment (IDE) for rapid application development (RAD) using the Free Pascal compiler. Its goal is to provide an easy-to-use development environment for programmers developing with the Object Pascal language, which is as close as possible to Delphi.');
    FPreviewLines.Add('');
    FPreviewLines.Add('Software developers use Lazarus to create native-code console and graphical user interface (GUI) applications for the desktop, and also for mobile devices, web applications, web services, visual components and function libraries for a number of different platforms, including Mac, Linux and Windows.');
    FPreviewLines.Add('');
    FPreviewLines.Add('A project created by using Lazarus on one platform can be compiled on any other one which Free Pascal compiler supports. For desktop applications a single source can target macOS, Linux, and Windows, with little or no modification. An example is the Lazarus IDE itself, created from a single code base and available on all major platforms including the Raspberry Pi.');
  finally
    Self.mmoPreview.Lines := FPreviewLines;
  end;
end;

procedure TfrmFont.FormDestroy(Sender: TObject);
begin
  FFont.Free;
  FPreviewLines.Free;
end;

procedure TfrmFont.lbFontsClick(Sender: TObject);
begin
  if (Sender as TListBox).ItemIndex < 0 then
    Exit;
  FFont.Name := (Sender as TListBox).Items.Strings[(Sender as TListBox).ItemIndex];
  mmoPreview.Font.Name := FFont.Name;
end;

procedure TfrmFont.btnColorColorChanged(Sender: TObject);
begin
  FFont.Color := btnColor.ButtonColor;
  mmoPreview.Font.Color := FFont.Color;
end;

procedure TfrmFont.seSizeChange(Sender: TObject);
begin
  FFont.Size := seSize.Value;
  mmoPreview.Font.Size := FFont.Size;
end;

procedure TfrmFont.SetCaption(const AValue: string);
begin
  FCaption := AValue;
  Caption := FCaption;
end;

procedure TfrmFont.SetTitleFonts(const AValue: string);
begin
  FTitleFonts := AValue;
  Self.lblFonts.Caption := FTitleFonts;
end;

procedure TfrmFont.SetTitleSize(const AValue: string);
begin
  FTitleSize := AValue;
  Self.lblSize.Caption := FTitleSize;
end;

procedure TfrmFont.SetTitleColor(const AValue: string);
begin
  FTitleColor := AValue;
  Self.lblColor.Caption := FTitleColor;
end;

procedure TfrmFont.SetTitleButton(const AValue: string);
begin
  FTitleButton := AValue;
  Self.btnOk.Caption := FTitleButton;
end;

procedure TfrmFont.SetPreviewLines(const AValue: TStringList);
begin
  FPreviewLines.Clear;
  FPreviewLines := AValue;
  Self.mmoPreview.Lines := FPreviewLines;
end;

end.
